@@ -197,14 +197,14 @@ static int sdla_te3_polling(sdla_fe_t *fe)
 				fe->name,prev_status,fe->fe_status,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout,
 				(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout)/HZ);
 
-	if (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout) {
+	if (1 || fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout) {
 		if (prev_status == FE_CONNECTED) {
 			if (fe->fe_status == FE_DISCONNECTED) {
 				DEBUG_TEST("%s: FE_DISCONNECTED checking timeout %lu\n",
 					fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout));
 	
-				if ((SYSTEM_TICKS-fe->fe_param.te3.disc_timeout) < (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout*HZ)) {
-					DEBUG_EVENT("%s: FE Disconnect within disc timeout %i\n",
+				if (1 || (SYSTEM_TICKS-fe->fe_param.te3.disc_timeout) < (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout*HZ)) {
+					DEBUG_EVENT("%s: FE Disconnect - resetting FE %i\n",
 								card->devname,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout);
 					sdla_te3_config(fe);
 				}
